"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const vscode_uri_1 = require("vscode-uri");
const ClientCapabilities_1 = require("../../ClientCapabilities");
const diagnostics_1 = require("../../diagnostics");
const documents_1 = require("../../documents");
const RunChecksProvider_1 = require("./RunChecksProvider");
(0, vitest_1.describe)('Unit: RunChecksProvider', () => {
    const uri1 = vscode_uri_1.URI.file('/path/to/file1.liquid').toString();
    const uri2 = vscode_uri_1.URI.file('/path/to/file2.liquid').toString();
    const contents1 = `
    {% assign x = 1 %}
    <script src="2.js"></script>
    <script src="3.js"></script>
  `;
    const contents2 = `
    {% assign y = 2 %}
    <script src="4.js"></script>
    <script src="5.js"></script>
  `;
    const version = 0;
    let connection;
    let documentManager;
    let diagnosticsManager;
    let clientCapabilities;
    let runChecks;
    let runChecksProvider;
    (0, vitest_1.beforeEach)(() => {
        connection = {};
        documentManager = new documents_1.DocumentManager();
        diagnosticsManager = new diagnostics_1.DiagnosticsManager(connection);
        clientCapabilities = new ClientCapabilities_1.ClientCapabilities();
        runChecks = vitest_1.vi.fn();
        runChecksProvider = new RunChecksProvider_1.RunChecksProvider(documentManager, diagnosticsManager, clientCapabilities, connection, runChecks);
        documentManager.open(uri1, contents1, version);
        documentManager.open(uri2, contents2, version);
    });
    (0, vitest_1.describe)('execute', () => {
        (0, vitest_1.it)('calls runChecks with the trigger URIs of all the open documents', async () => {
            await runChecksProvider.execute();
            (0, vitest_1.expect)(runChecks).toHaveBeenCalledWith([uri1, uri2]);
        });
    });
});
//# sourceMappingURL=RunChecksProvider.spec.js.map