"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HoverProvider = void 0;
const theme_check_common_1 = require("@shopify/theme-check-common");
const TypeSystem_1 = require("../TypeSystem");
const visitor_1 = require("../visitor");
const providers_1 = require("./providers");
const HtmlAttributeValueHoverProvider_1 = require("./providers/HtmlAttributeValueHoverProvider");
class HoverProvider {
    constructor(documentManager, themeDocset) {
        this.documentManager = documentManager;
        this.themeDocset = themeDocset;
        this.providers = [];
        const typeSystem = new TypeSystem_1.TypeSystem(themeDocset);
        this.providers = [
            new providers_1.LiquidTagHoverProvider(themeDocset),
            new providers_1.LiquidFilterHoverProvider(themeDocset),
            new providers_1.LiquidObjectHoverProvider(typeSystem),
            new providers_1.LiquidObjectAttributeHoverProvider(typeSystem),
            new providers_1.HtmlTagHoverProvider(),
            new providers_1.HtmlAttributeHoverProvider(),
            new HtmlAttributeValueHoverProvider_1.HtmlAttributeValueHoverProvider(),
        ];
    }
    async hover(params) {
        var _a;
        const uri = params.textDocument.uri;
        const document = this.documentManager.get(uri);
        // Supports only Liquid resources
        if ((document === null || document === void 0 ? void 0 : document.type) !== theme_check_common_1.SourceCodeType.LiquidHtml || document.ast instanceof Error) {
            return null;
        }
        const [currentNode, ancestors] = findCurrentNode(document.ast, document.textDocument.offsetAt(params.position));
        const promises = this.providers.map((p) => p.hover(currentNode, ancestors));
        const results = await Promise.all(promises);
        return (_a = results.find(Boolean)) !== null && _a !== void 0 ? _a : null;
    }
}
exports.HoverProvider = HoverProvider;
function findCurrentNode(ast, cursorPosition) {
    let prev;
    let current = ast;
    let ancestors = [];
    while (current !== prev) {
        prev = current;
        (0, visitor_1.forEachChildNodes)(current, ancestors.concat(current), (child, lineage) => {
            if (isCovered(child, cursorPosition) && size(child) <= size(current)) {
                current = child;
                ancestors = lineage;
            }
        });
    }
    return [current, ancestors];
}
function isCovered(node, offset) {
    return node.position.start <= offset && offset <= node.position.end;
}
function size(node) {
    return node.position.end - node.position.start;
}
//# sourceMappingURL=HoverProvider.js.map