"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const documents_1 = require("../../documents");
const HoverProvider_1 = require("../HoverProvider");
(0, vitest_1.describe)('Module: LiquidFilterHoverProvider', async () => {
    let provider;
    (0, vitest_1.beforeEach)(async () => {
        provider = new HoverProvider_1.HoverProvider(new documents_1.DocumentManager(), {
            filters: async () => [
                {
                    name: 'upcase',
                    syntax: 'string | upcase',
                    description: 'upcase description',
                    return_type: [{ type: 'string', name: '' }],
                },
            ],
            objects: async () => [],
            tags: async () => [],
        });
    });
    (0, vitest_1.it)('should return the hover description of the object', async () => {
        const contexts = [
            '{{ foo | upc█ase }}',
            '{{ foo | upcase█ }}',
            '{% echo foo | upcase█ %}',
            '{% liquid\n echo foo | upcase█ %}',
        ];
        for (const context of contexts) {
            await (0, vitest_1.expect)(provider).to.hover(context, vitest_1.expect.stringMatching(/##* upcase+: `string`/));
            await (0, vitest_1.expect)(provider).to.hover(context, vitest_1.expect.stringContaining('upcase description'));
        }
    });
    (0, vitest_1.it)('should return nothing if the thing is unknown', async () => {
        await (0, vitest_1.expect)(provider).to.hover(`{{ foo | unknown█ }}`, null);
    });
});
//# sourceMappingURL=LiquidFilterHoverProvider.spec.js.map