/// <reference types="node" />
import { EventEmitter } from 'node:events';
import { createConnection } from 'vscode-languageserver/lib/common/server';
type MockConnectionMethods = {
    /**
     * Trigger all appropriate onNotification handlers on the connection
     */
    triggerNotification: ReturnType<typeof createConnection>['sendNotification'];
    /**
     * Trigger all appropriate onRequest handlers on the connection
     */
    triggerRequest: ReturnType<typeof createConnection>['sendRequest'];
    /**
     * Perform the initialize/initialized lifecycle methods
     */
    setup(): void;
    /**
     * Perform the textDocument/didOpen notification
     */
    openDocument(relativePath: string, contents: string): void;
    /**
     * Perform the textDocument/didChange notification
     */
    changeDocument(relativePath: string, contents: string, version: number): void;
    /**
     * Perform the textDocument/didClose notification
     */
    closeDocument(relativePath: string): void;
    spies: ReturnType<typeof protocolConnection>;
};
/**
 * A mock connection behaves like a real connection, except we can trigger
 * messages manually via the extra MockConnectionMethods.
 */
export type MockConnection = ReturnType<typeof createConnection> & MockConnectionMethods;
declare function protocolConnection(requests: EventEmitter, notifications: EventEmitter): {
    dispose: import("@vitest/spy").Mock<[], void>;
    end: import("@vitest/spy").Mock<[], void>;
    hasPendingResponse: import("@vitest/spy").Mock<[], boolean>;
    listen: import("@vitest/spy").Mock<[], void>;
    onClose: import("@vitest/spy").Mock<[listener: (e: void) => any, thisArgs?: any, disposables?: import("vscode-languageserver").Disposable[] | undefined], import("vscode-languageserver").Disposable>;
    onDispose: import("@vitest/spy").Mock<[listener: (e: void) => any, thisArgs?: any, disposables?: import("vscode-languageserver").Disposable[] | undefined], import("vscode-languageserver").Disposable>;
    onError: import("@vitest/spy").Mock<[listener: (e: [Error, import("vscode-languageserver").Message | undefined, number | undefined]) => any, thisArgs?: any, disposables?: import("vscode-languageserver").Disposable[] | undefined], import("vscode-languageserver").Disposable>;
    onProgress: import("@vitest/spy").Mock<[type: import("vscode-languageserver").ProgressType<P>, token: string | number, handler: import("vscode-languageserver").NotificationHandler<P>], import("vscode-languageserver").Disposable>;
    onNotification: import("@vitest/spy").Mock<any, any>;
    onRequest: import("@vitest/spy").Mock<any, any>;
    onUnhandledNotification: import("@vitest/spy").Mock<[listener: (e: import("vscode-languageserver").NotificationMessage) => any, thisArgs?: any, disposables?: import("vscode-languageserver").Disposable[] | undefined], import("vscode-languageserver").Disposable>;
    sendNotification: import("@vitest/spy").Mock<any, any>;
    sendProgress: import("@vitest/spy").Mock<[type: import("vscode-languageserver").ProgressType<P_1>, token: string | number, value: P_1], Promise<void>>;
    sendRequest: any;
    trace: import("@vitest/spy").Mock<any, any>;
};
export declare function mockConnection(): MockConnection;
export {};
